OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "최근 상태",
    "No recent status changes" : "최근 상태 변경 없음",
    "In a meeting" : "회의 중",
    "Commuting" : "이동 중",
    "Out sick" : "병가",
    "Vacationing" : "휴가 중",
    "Out of office" : "자리에 없음",
    "Working remotely" : "원격 근무 중",
    "In a call" : "통화중",
    "User status" : "사용자 상태",
    "Clear status after" : "상태 메시지 지우기 예약",
    "What is your status?" : "당신의 상태는?",
    "Set status" : "상태 설정",
    "Online status" : "접속 상태",
    "Status message" : "상태 메시지",
    "Clear status message" : "상태 메시지 지움",
    "Set status message" : "상태 메시지 설정",
    "There was an error saving the status" : "상태 저장에 오류가 발생했습니다.",
    "There was an error clearing the status" : "상태 해제에 오류가 발생했습니다.",
    "Don't clear" : "지우지 않음",
    "Today" : "오늘",
    "This week" : "이번 주",
    "Online" : "접속 중",
    "Away" : "자리 비움",
    "Do not disturb" : "방해 금지",
    "Invisible" : "숨겨짐",
    "Offline" : "오프라인",
    "There was an error saving the new status" : "새로운 상태 저장에 오류가 발생했습니다.",
    "30 minutes" : "30 분",
    "1 hour" : "한 시간",
    "4 hours" : "4 시간",
    "Mute all notifications" : "모든 알림을 음소거",
    "Appear offline" : "접속 안함으로 표시",
    "View profile" : "프로필 보기",
    "{status}, {timestamp}" : "{status},{timestamp}"
},
"nplurals=1; plural=0;");
